PIPS = ["Ace", "Two", "Three", "Four", "Five", "Six", "Seven",
        "Eight", "Nine", "Ten", "Page", "Knight", "Queen", "King"]

SUITS = [ "Swords", "Cups", "Wands", "Coins" ]

TAROT_TRUMPS = {
        "The Fool": None,
        "The Magician": 1,
        "The High Priestess": 2,
        "The Empress": 3,
        "The Emperor": 4,
        "The Hierophant": 5,
        "The Lovers": 6,
        "The Chariot": 7,
        "Strength": 8,
        "The Hermit": 9,
        "Wheel of Fortune": 10,
        "Justice": 11,
        "The Hanged Man": 12,
        "Death": 13,
        "Temperance": 14,
        "The Devil": 15,
        "The Tower": 16,
        "The Star": 17,
        "The Moon": 18,
        "The Sun": 19,
        "Judgment": 20,
        "The World": 21
        }

MINCHIATE_TRUMPS = {
        "The Madman": None,
        "Pope One: Ganellino": 1,
        "Pope Two: The Empress": 2,
        "Pope Three: The Emperor": 3,
        "Pope Four: The Pope": 4,
        "Pope Five: The Lovers": 5,
        "Temperance": 6,
        "Fortitude": 7,
        "Justice": 8,
        "Wheel of Fortune": 9,
        "The Chariot": 10,
        "The Hunchback; Time": 11,
        "The Hanged Man; The Traitor": 12,
        "Death": 13,
        "The Devil": 14,
        "House of the Devil": 15,
        "Hope": 16,
        "Prudence": 17,
        "Faith": 18,
        "Charity": 19,
        "Fire": 20,
        "Water": 21,
        "Earth": 22,
        "Air": 23,
        "Libra": 24,
        "Virgo": 25,
        "Scorpio": 26,
        "Aries": 27,
        "Capricorn": 28,
        "Sagittarius": 29,
        "Cancer": 30,
        "Pisces": 31,
        "Aquarius": 32,
        "Leo": 33,
        "Taurus": 34,
        "Gemini": 35,
        "The Star": None,
        "The Moon": None,
        "The Sun": None,
        "The World": None,
        "The Trumpets": None
        }
